@@ -4,8 +4,9 @@ from .c_gen import FileCGen
 from .ts_gen import FileTsGen
 from .py_gen import FilePyGen
 from .gql_gen import FileGqlGen
+from .cpp_gen import FileCppGen
 
 from .generate import main
 
-__all__ = ["main", "FileCGen", "FileTsGen", "FilePyGen", "FileGqlGen", "version",
+__all__ = ["main", "FileCGen", "FileTsGen", "FilePyGen", "FileGqlGen", "FileCppGen", "version",
            "NamingStyleC", "CamelToSnakeCase", "pascalCase"]
